@@ -230,6 +230,7 @@ class SmartDriver(SeleniumDriverCore):
                         'label': element_name,
                         'test_case_name': self.test_case_uuid,
                         'do_exact_match_first': self.do_exact_match_first,
+                        'exact_match_first_threshold': self.exact_match_first_threshold,
                         }
                 start = time.time()
                 response = self.make_json_post_request('/detect', data, self.detect_timeout_message, self.detect_timeout)
@@ -283,7 +284,9 @@ class SmartDriver(SeleniumDriverCore):
                     'source': '',
                     'api_key': self.api_key,
                     'label': element_name,
-                    'test_case_name': self.test_case_uuid}
+                    'test_case_name': self.test_case_uuid,
+                    'do_exact_match_first': self.do_exact_match_first,
+                    'exact_match_first_threshold': self.exact_match_first_threshold,}
             r = self.make_json_post_request('/detect', data, self.detect_timeout_message, self.detect_timeout)
             if r['success']:
                 return r
