@@ -64,6 +64,7 @@ class SeleniumDriverCore(object):
         self.detect_timeout = initialization_options.get('detect_timeout', 60)
         self.misc_timeout = initialization_options.get('misc_timeout', 10)
         self.do_exact_match_first = initialization_options.get('do_exact_match_first', False)
+        self.exact_match_first_threshold = initialization_options.get('exact_match_first_threshold', 0.999)
 
         self.url = initialization_options.get('server_url',
                 os.environ.get('DEVTOOLSAI_URL', 'https://smartdriver.dev-tools.ai'))
@@ -625,7 +626,10 @@ class SeleniumDriverCore(object):
         data = {'api_key': self.api_key, 'label': label,
                 'screenshot_uuid': self.last_test_case_screenshot_uuid,
                 'run_classifier': self.use_classifier_during_creation,
-                'event_id': event_id}
+                'event_id': event_id,
+                'do_exact_match_first': self.do_exact_match_first,
+                'exact_match_first_threshold': self.exact_match_first_threshold,
+                }
 
         needs_reload = False
         r = self.make_json_post_request('/testcase/get_action_info', data, self.misc_timeout_message, max(15, self.misc_timeout))
